<?php
// $Id: iContact.class.inc,v 1.1.2.1 2009/08/17 23:33:50 greenskin Exp $

define('ICONTACT_CODE_SUCCESS', 200);
define('ICONTACT_CODE_BAD_REQUEST', 400);
define('ICONTACT_CODE_NOT_AUTHORIZED', 401);
define('ICONTACT_CODE_PAYMENT_REQUIRED', 402);
define('ICONTACT_CODE_FORBIDDEN', 403);
define('ICONTACT_CODE_NOT_FOUND', 404);
define('ICONTACT_CODE_METHOD_NOT_ALLOWED', 405);
define('ICONTACT_CODE_NOT_ACCEPTABLE', 406);
define('ICONTACT_CODE_UNSUPPORTED_FORMAT', 415);
define('ICONTACT_CODE_INTERAL_SERVER_ERROR', 500);
define('ICONTACT_CODE_NOT_IMPLEMENTED', 501);
define('ICONTACT_CODE_SERVICE_UNAVAILABLE', 503);
define('ICONTACT_CODE_INSUFFICIENT_SPACE', 507);

class iContact extends iContactResource {
  private $url = '';
  private $app_id = '';
  private $username = '';
  private $password = '';
  protected $type = 'iContact';
  public $dataType = 'xml';
  public $accounts = array();

  public function __construct($refresh = FALSE) {
    $this->app_id = variable_get('icontact_app_id', ICONTACT_TEST_APP_ID);
    if ($this->app_id == ICONTACT_APP_ID) {
      $this->url = ICONTACT_URL;
      $this->username = variable_get('icontact_username', '');
      $this->password = variable_get('icontact_password', '');
    }
    else {
      $this->url = ICONTACT_TEST_URL;
      $this->username = variable_get('icontact_test_username', '');
      $this->password = variable_get('icontact_test_password', '');
    }
    $this->iContactId = $this->username;

    if ($refresh) {
      cache_clear_all(NULL, 'cache_icontact');
    }
    $this->init();
  }

  protected function collapse() {
    $array = array();
    foreach ($this as $key => $value) {
      switch ($key) {
        case 'url':
        case 'app_id':
        case 'username':
        case 'password':
          break;
        case 'accounts':
          $array[$key] = array();
          foreach ($value as $k => $v) {
            $array[$key][$k] = $k;
          }
          break;
        default:
          $array[$key] = $value;
          break;
      }
    }
    return $array;
  }

  protected function expand() {
    if (!empty($this->accounts)) {
      foreach ($this->accounts as $k => $v) {
        if (is_int($v)) {
          $this->accounts[$k] = new iContactAccount($this, $v);
        }
      }
    }
  }

  protected function defaults() {
    return array();
  }

  public function init($data = NULL) {
    if ($data === NULL) {
      if ($this->load()) {
        return TRUE;
      }
    }
    else {
      foreach ($data as $key => $value) {
        switch ($key) {
          default:
            $this->$key = $value;
            break;
        }
      }
    }

    if (method_exists($this, 'setResources')) {
      $this->setResources();
    }
    foreach ($this->resources as $type => $uri) {
      $this->loadResource($type, $uri);
    }
    return TRUE;
  }

  public function load() {
    return $this->getCache($this->username);
  }

  protected function setResources() {
    $this->resources = array('account' => '/a');
  }

  public function checkLoggedIn() {
    static $loggedIn = NULL;

    if ($loggedIn !== NULL) {
      return $loggedIn;
    }

    $result = $this->request('/a');
    $loggedIn = ($result->code != ICONTACT_CODE_NOT_AUTHORIZED) ? TRUE : FALSE;
    return $loggedIn;
  }

  public function request($uri, $method = 'GET', $data = NULL, $retry = 3) {
    $url = $this->url . $uri;
    $headers = array(
      'API-Version' => '2.0',
      'Accept' => 'application/'. $this->dataType,
      'API-AppId' => $this->app_id,
      'API-Username' => $this->username,
      'API-Password' => $this->password,
      'Content-Type' => 'application/'. $this->dataType
    );
    return drupal_http_request($url, $headers, $method, $data, $retry);
  }

  public function requestData($uri, $method = 'GET', $data = NULL, $retry = 3) {
    $result = $this->request($uri, $method, $data, $retry);
    if ($result->code != ICONTACT_CODE_SUCCESS) {
      drupal_set_message(t('iContact error: %error', array('%error' => $this->statusMessage($result->code))), 'error');
      return FALSE;
    }
    $func = 'requestData'. ucwords($this->dataType);
    return $this->requestDataXml($result->data);
  }

  private function requestDataXml($data) {
    if ($result = simplexml_load_string($data)) {
      return (array)$result;
    }
    return FALSE;
  }

  private function requestDataJson($data) {
    if (is_string($data) && $result = json_decode($data)) {
      return (array)$array;
    }
    return FALSE;
  }
}
