<?php
// $Id: iContactClientFolder.class.inc,v 1.1.2.5 2009/08/21 23:33:15 greenskin Exp $

class iContactClientFolder extends iContactResource {
  protected $type = 'clientFolder';
  public $accountId;
  public $clientFolderId;
  public $contacts = array();
  public $lists = array();
  public $messages = array();
  public $subscriptions = array();

  public function __construct(iContactAccount $account, $clientFolder = NULL) {
    $this->accountId = $account->accountId;
    $this->uri = '/a/'. $this->accountId .'/c';

    parent::__construct($account->iContact, $clientFolder);
  }

  protected function collapse() {
    $array = array();
    foreach ($this as $key => $value) {
      switch ($key) {
        case 'uri':
        case 'type':
        case 'iContact':
          break;
        case 'contacts':
        case 'lists':
        case 'messages':
        case 'subscriptions':
          $array[$key] = array();
          foreach ($value as $k => $v) {
            $array[$key][$k] = $k;
          }
          break;
        default:
          $array[$key] = $value;
          break;
      }
    }
    return $array;
  }

  protected function expand() {
    if (!empty($this->contacts)) {
      foreach ($this->contacts as $k => $v) {
        if (is_int($v)) {
          $this->contacts[$k] = new iContactContact($this, $v);
        }
      }
    }
    if (!empty($this->lists)) {
      foreach ($this->lists as $k => $v) {
        if (is_int($v)) {
          $this->lists[$k] = new iContactList($this, $v);
        }
      }
    }
    if (!empty($this->messages)) {
      foreach ($this->messages as $k => $v) {
        if (is_int($v)) {
          $this->messages[$k] = new iContactMessage($this, $v);
        }
      }
    }
    if (!empty($this->subscriptions)) {
      foreach ($this->subscriptions as $k => $v) {
        if (is_string($v)) {
          $this->subscriptions[$k] = new iContactSubscription($this, $v);
        }
      }
    }
  }

  protected function defaults() {
    return array(
      'name' => '',
      'fromName' => '',
      'fromEmail' => '',
      'street' => '',
      'city' => '',
      'state' => '',
      'postalCode' => '',
      'country' => '',
      'logoId' => 0,
      'enabled' => 1,
      'footerLogoUrl' => '',
      'useLogoInFooter' => 0,
      'emailRecipient' => ''
    );
  }

  protected function setResources() {
    $this->resources = array(
      'contact' => '/a/'. $this->accountId .'/c/'. $this->clientFolderId .'/contacts',
      'list' => '/a/'. $this->accountId .'/c/'. $this->clientFolderId .'/lists',
      'subscription' => '/a/'. $this->accountId .'/c/'. $this->clientFolderId .'/subscriptions',
      'message' => '/a/'. $this->accountId .'/c/'. $this->clientFolderId .'/messages'
    );
  }

  function listContacts($query = NULL) {
    $contacts = array();
    if ($query === NULL) {
      // Quick call to get the total number of contacts.
      $query = drupal_query_string_encode(array('status' => 'total', 'limit' => 0));
      $request = '/a/'. $this->accountId .'/c/'. $this->clientFolderId .'/contacts?'. $query;
      $result = $this->requestData($request);

      // Now retrieve all contacts.
      $query = drupal_query_string_encode(array('status' => 'total', 'limit' => (int)$result['total']));
      $result = $this->listContacts($query);
      if (!empty($result)) {
        $contacts += $result;
      }
    }
    else {
      $request = '/a/'. $this->accountId .'/c/'. $this->clientFolderId .'/contacts';
      if ($query !== NULL) $request .= '?'. $query;
      $result = $this->requestData($request);
      if (is_object($result['contacts'])) {
        foreach ($result['contacts']->children() as $contact) {
          if (!isset($this->contacts[(int)$contact->contactId]) || !is_object($this->contacts[(int)$contact->contactId])) {
            $cache = TRUE;
            $this->contacts[(int)$contact->contactId] = new iContactContact($this, $contact);
            $this->contacts[(int)$contact->contactId]->setCache();
          }
          $contacts[(int)$contact->contactId] = $contact;
        }
        if (isset($cache) && $cache) {
          $this->setCache();
        }
      }
    }
    if (!empty($contacts)) {
      return $contacts;
    }
    return FALSE;
  }

  function listLists() {
    $request = '/a/'. $this->accountId .'/c/'. $this->clientFolderId .'/lists';
    $result = $this->requestData($request);
    if (is_object($result['lists'])) {
      $lists = array();
      foreach ($result['lists']->children() as $list) {
        $lists[(int)$list->listId] = $list;
      }
      return $lists;
    }
    return FALSE;
  }

  function listMessages($type = NULL) {
    $request = '/a/'. $this->accountId .'/c/'. $this->clientFolderId .'/messages';
    $result = $this->requestData($request);
    if (is_object($result['messages'])) {
      $messages = array();
      foreach ($result['messages']->children() as $message) {
        if ($type != NULL && $type != $message->messageType) {
          continue;
        }
        $messages[(int)$message->messageId] = $message;
      }
      return $messages;
    }
    return FALSE;
  }

  function listSubscriptions() {
    $request = '/a/'. $this->account->accountId .'/c/'. $this->clientFolderId .'/subscriptions';
    $result = $this->account->icontact->requestData($request);
    if (is_object($result)) {
      $subscriptions = array();
      foreach ($result->subscriptions->children() as $subscription) {
        $subscriptions[(string)$subscription->subscriptionId] = $subscription;
      }
      return $subscriptions;
    }
    return FALSE;
  }
}
