<?php
// $Id: iContactResource.class.inc,v 1.1.2.7 2009/08/22 00:04:48 greenskin Exp $

abstract class iContactResource {
  protected $type;
  protected $uri = '';
  protected $resources = array();

  public function __construct(iContact &$icontact, $resource = NULL) {
    $this->iContact = $icontact;
    $this->init($resource);
  }

  abstract protected function collapse();
  abstract protected function expand();
  abstract protected function defaults();

  public function setCache() {
    $resourceId = $this->type .'Id';
    if (!empty($this->$resourceId)) {
      cache_set($this->type .':'. $this->$resourceId, $this->collapse(), 'cache_icontact');
    }
  }

  public function getCache($resourceId) {
    if ($cache = cache_get($this->type .':'. $resourceId, 'cache_icontact')) {
      $this->init($cache->data);
      $this->expand();
      return TRUE;
    }
    return FALSE;
  }

  public function init($resource) {
    if ($resource === NULL) {
      $resource = $this->defaults();
    }
    if (is_integer($resource) || is_string($resource)) {
      return $this->load((string)$resource);
    }
    else {
      foreach ($resource as $key => $value) {
        switch ($key) {
          default:
            $this->$key = (is_object($value) && get_class($value) == 'SimpleXMLElement') ? (string)$value : $value;
            break;
        }
      }
      if (method_exists($this, 'setResources')) {
        $this->setResources();
      }
      foreach ($this->resources as $type => $uri) {
        $this->loadResource($type, $uri);
      }
    }
    return TRUE;
  }

  public function load($resourceId = NULL) {
    if ($resourceId === NULL) $resourceId = $this->resourceId;
    if ($resourceId > 0) {
      if ($data = $this->getCache($resourceId)) {
        return TRUE;
      }

      $result = $this->iContact->requestData($this->uri .'/'. $resourceId);
      if (!empty($result)) {
        if ($this->init($result[strtolower($this->type)])) {
          $this->setCache();
          return TRUE;
        }
      }
    }
    return FALSE;
  }

  function save($edit) {
    if (is_array($edit)) $edit = (object)$edit;

    $resourceId = $this->type .'Id';

    if (isset($edit->$resourceId) && $edit->$resourceId > 0) {
      $xml_txt = "<{$this->type}></{$this->type}>";
      $xml_obj = simplexml_load_string($xml_txt);
      foreach ($edit as $key => $value) {
        $xml_obj->addChild($key, $value);
      }
      $uri = $this->uri .'/'. $edit->$resourceId;
      $data = $this->iContact->requestData($uri, 'POST', $xml_obj->asXML());
      if (isset($data->warnings->warning)) {
        drupal_set_message((string)$data->warnings->warning);
        $success = FALSE;
      }
      $success = TRUE;
    }
    else {
      $xml_txt = "<{$this->type}s><{$this->type}></{$this->type}></{$this->type}s>";
      $xml_obj = simplexml_load_string($xml_txt);
      foreach ($edit as $key => $value) {
        $xml_obj->user->addChild($key, $value);
      }
      $uri = $this->uri;
      $data = $this->iContact->requestData($uri, 'POST', $xml_obj->asXML());
      if (isset($data->warnings->warning)) {
        drupal_set_message((string)$data->warnings->warning);
        $success = FALSE;
      }
      $success = TRUE;
    }
    if ($success) {
      $this->init($edit);
    }
    return $success;
  }

  function delete() {
    $uri = $this->uri .'/'. $this->messageId;
    $result = $this->icontact->request($uri, 'DELETE');
    dpm($uri);
    dpm($result);
  }

  public function loadResource($type, $uri = NULL) {
    $type_plural = $type .'s';
    if (!empty($this->$type_plural)) {
      foreach ($this->$type_plural as $resourceId => $resource) {
        if (is_object($resource)) {
          $this->{$type_plural}[$resourceId]->load();
        }
        else {
          $class = 'iContact'. ucwords($type);
          if ($cache = cache_get($type .':'. $resourceId, 'cache_icontact')) {
            $this->{$type_plural}[$resourceId] = new $class($this, $cache->data);
          }
          else {
            $this->{$type_plural}[$resourceId] = new $class($this, $resourceId);
          }
        }
      }
    }
    else if ($uri != NULL) {
      if ($result = $this->requestData($uri)) {
        $lower = strtolower($type_plural);
        if (get_class($result[$lower]) == 'SimpleXMLElement') {
          foreach ($result[$lower]->children() as $resource) {
            $class = 'iContact'. ucwords($type);
            $resourceId = $type .'Id';
            $this->{$type_plural}[(string)$resource->$resourceId] = new $class($this, (string)$resource->$resourceId);
            $this->{$type_plural}[(string)$resource->$resourceId]->setCache();
          }
        }
        else {
          foreach ($result[$lower] as $resource) {
            $class = 'iContact'. ucwords($type);
            $resourceId = $type .'Id';
            $this->{$type_plural}[(string)$resource->$resourceId] = new $class($this, (string)$resource->$resourceId);
            $this->{$type_plural}[(string)$resource->$resourceId]->setCache();
          }
        }
        $this->setCache();
      }
    }
  }

  public function request($uri, $method = 'GET', $data = NULL, $retry = 3) {
    return $this->iContact->request($uri, $method, $data, $retry);
  }

  public function requestData($uri, $method = 'GET', $data = NULL, $retry = 3) {
    return $this->iContact->requestData($uri, $method, $data, $retry);
  }

  protected function statusMessage($code) {
    switch ($code) {
      case ICONTACT_CODE_SUCCESS:
        return 'Your request was processed successfully.';
      case ICONTACT_CODE_BAD_REQUEST:
        return 'Your data could not be parsed or your request contained invalid data.';
      case ICONTACT_CODE_NOT_AUTHORIZED:
        return 'You are not logged in.';
      case ICONTACT_CODE_PAYMENT_REQUIRED:
        return 'You must pay your iContact bill before we can process your request.';
      case ICONTACT_CODE_FORBIDDEN:
        return 'You are logged in, but do not have permission to perform that action.';
      case ICONTACT_CODE_NOT_FOUND:
        return 'You have requested a resource that cannot be found.';
      case ICONTACT_CODE_METHOD_NOT_ALLOWED:
        return 'You cannot perform that method on the requested resource.';
      case ICONTACT_CODE_NOT_ACCEPTABLE:
        return 'You have requested that iContact generate data in an unsupported format. The iContact API can only return data in XML or JSON.';
      case ICONTACT_CODE_UNSUPPORTED_FORMAT:
        return 'Your request was not in a supported format. You can make requests in XML or JSON.';
      case ICONTACT_CODE_INTERAL_SERVER_ERROR:
        return "An error occurred in iContact's code.";
      case ICONTACT_CODE_NOT_IMPLEMENTED:
        return 'You have requested a resource that has not been implemented or you have specified an incorrect version of the iContact API.';
      case ICONTACT_CODE_SERVICE_UNAVAILABLE:
        return 'You cannot perform the action because the system is experiencing extremely high traffic or you cannot perform the action because the system is down for maintenance.';
      case ICONTACT_CODE_INSUFFICIENT_SPACE:
        return 'You have used up all of your allotted storage (for example, in the image library).';
      default:
        return 'An error occurred.';
    }
  }
}
