<?php
// $Id: icontact_lists.admin.inc,v 1.1.2.3 2009/08/07 20:07:25 greenskin Exp $

/*******************************************************************************
 * Callback Functions, Forms, and Tables
 ******************************************************************************/

/**
 * iContact accounts administrative section.
 */
function icontact_lists_list() {
  if (isset($_GET['clientFolderId']) && $_GET['clientFolderId'] > 0) {
    $icontact = icontact_load();
    if ($accountId = $icontact->getAccountId('clientFolders', $_GET['clientFolderId'])) {
      if (isset($icontact->accounts[$accountId]->clientFolders[$_GET['clientFolderId']])) {
        icontact_clientfolders_breadcrumb($accountId);
        $lists = $icontact->accounts[$accountId]->clientFolders[$_GET['clientFolderId']]->listLists();
        $add = '<div>'. l(t('Add list'), 'admin/icontact/lists/add/'. $_GET['clientFolderId']) .'</div>';
        return $add . theme('icontact_lists_list', $lists);
      }
    }
  }
  drupal_not_found();
}

function icontact_lists_view($list) {
  icontact_lists_breadcrumb($list->clientFolder->account->accountId, $list->clientFolder->clientFolderId);

  $contacts = array();
  foreach ($list->clientFolder->contactIds as $contactId) {
    if (isset($list->clientFolder->subscriptions[$list->listId .'_'. $contactId])) {
      $contacts[$contactId] = $contactId;
    }
  }
  return theme('icontact_lists_view', $list, $contacts);
}

function icontact_lists_form(&$form_state, $list) {
  if (get_class($list) == 'iContactClientFolder') {
    $list = new iContactList($list);
  }

  icontact_lists_breadcrumb($list->clientFolder->account->accountId, $list->clientFolder->clientFolderId);

  if (is_array($list)) $list = (object)$list;

  $form_state['list'] = $list;
  $form = array('list' => array('#tree' => TRUE));
  if (isset($list->listId) && $list->listId > 0) {
    $form['list']['listId'] = array(
      '#type' => 'hidden',
      '#value' => $list->listId
    );
  }
  $form['list']['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name'),
    '#default_value' => $list->name,
    '#required' => TRUE
  );
  $form['list']['emailOwnerOnChange'] = array(
    '#type' => 'checkbox',
    '#title' => t('Email owner on change'),
    '#default_value' => $list->emailOwnerOnChange
  );
  $form['list']['welcomeOnManualAdd'] = array(
    '#type' => 'checkbox',
    '#title' => t('Welcome on manual add'),
    '#default_value' => $list->welcomeOnManualAdd
  );
  $form['list']['welcomeOnSignupAdd'] = array(
    '#type' => 'checkbox',
    '#title' => t('Welcome on signup add'),
    '#default_value' => $list->welcomeOnSignupAdd
  );
  $message_options = array();
  foreach ($list->clientFolder->listMessages('welcome') as $message) {
    $message_options[$message['messageId']] = $message['subject'];
  }
  $form['list']['welcomeMessageId'] = array(
    '#type' => 'select',
    '#title' => t('Welcome message'),
    '#default_value' => $list->welcomeMessageId,
    '#options' => $message_options,
    '#required' => TRUE
  );
  $form['list']['description'] = array(
    '#type' => 'textarea',
    '#title' => t('Description'),
    '#default_value' => $list->description
  );
  $form['save'] = array(
    '#type' => 'submit',
    '#value' => t('Save')
  );
  return $form;
}

function icontact_lists_form_submit($form, &$form_state) {
  $list = $form_state['list'];

  if ($result = $list->save($form_state['values']['list'])) {
    if (isset($form_state['values']['list']['listId']) && $form_state['values']['list']['listId'] > 0) {
      drupal_set_message(t('List successfully updated.'));
    }
    else {
      drupal_set_message(t('List successfully created.'));
      $form_state['redirect'] = array('admin/icontact/lists', array('clientFolderId' => $list->clientFolder->clientFolderId));
    }
  }
}

/*******************************************************************************
 * Theme Functions
 ******************************************************************************/

function theme_icontact_lists_list($lists) {
  $output = '';
  $headers = array(
    t('Name'),
    t('Actions')
  );
  $rows = array();
  $destination = drupal_get_destination();
  $actions = array(
    'view' => array(
      'title' => t('View contacts'),
      'href' => '',
      'query' => $destination
    ),
    'edit' => array(
      'title' => t('Edit'),
      'href' => '',
      'query' => $destination
    )
  );
  foreach ($lists as $list) {
    $actions['view']['href'] = 'admin/icontact/lists/'. $list['listId'] .'/view';
    $actions['edit']['href'] = 'admin/icontact/lists/'. $list['listId'] .'/edit';
    $row = array(
      array('data' => $list['name']),
      array('data' => theme('links', $actions))
    );
    $rows[] = array('data' => $row);
  }

  $output = '<div>'. theme('table', $headers, $rows) .'</div>';
  return $output;
}

function theme_icontact_lists_view($list, $contacts) {
  $headers = array(
    t('First name'),
    t('Last name'),
    t('Status'),
    t('Actions')
  );
  $rows = array();
  $actions = array(
    'edit' => array(
      'title' => t('Edit'),
      'href' => '',
      'query' => drupal_get_destination()
    ),
    'history' => array(
      'title' => t('History'),
      'href' => ''
    )
  );
  foreach ($contacts as $contactId) {
    $actions['edit']['href'] = 'admin/icontact/contacts/'. $contactId .'/edit';
    $actions['history']['href'] = 'admin/icontact/contacts/'. $contactId .'/history';
    $row = array(
      array('data' => $list->clientFolder->contacts[$contactId]->firstName),
      array('data' => $list->clientFolder->contacts[$contactId]->lastName),
      array('data' => $list->clientFolder->subscriptions[$list->listId .'_'. $contactId]->status),
      array('data' => theme('links', $actions))
    );
    $rows[] = $row;
  }

  $output = theme('table', $headers, $rows);
  return $output;
}
