<?php
// $Id: icontact_ui.messages.inc,v 1.1.2.1 2009/08/21 23:33:15 greenskin Exp $

/*******************************************************************************
 * Callback Functions, Forms, and Tables
 ******************************************************************************/

/**
 * iContact accounts administrative section.
 */
function icontact_ui_messages_list() {
  if (isset($_GET['clientFolderId']) && $_GET['clientFolderId'] > 0) {
    $icontact = icontact_load();
    $clientFolderId = $_GET['clientFolderId'];
    foreach ($icontact->accounts as $accountId => $account) {
      if (isset($account->clientFolders[$clientFolderId])) {
        icontact_ui_breadcrumb('clientFolder', array('accountId' => $accountId));
        $messages = $account->clientFolders[$clientFolderId]->listMessages();
        $add = '<div>'. l(t('Add message'), 'admin/icontact/messages/add/'. $clientFolderId) .'</div>';
        return $add . theme('icontact_ui_messages_list', $messages);
      }
    }
  }
  drupal_not_found();
}

function icontact_ui_messages_form(&$form_state, $message) {
  if (get_class($message) == 'iContactClientFolder') {
    $message = new iContactMessage($message);
  }

  icontact_ui_breadcrumb('message', array('accountId' => $message->accountId, 'clientFolderId' => $message->clientFolderId));

  if (is_array($message)) $message = (object)$message;

  $form_state['message'] = $message;
  $form = array('message' => array('#tree' => TRUE));
  if (isset($message->messageId) && $message->messageId > 0) {
    $form['message']['messageId'] = array(
      '#type' => 'hidden',
      '#value' => $message->messageId
    );
  }
  $form['message']['messageType'] = array(
    '#type' => 'select',
    '#title' => t('Message type'),
    '#default_value' => $message->messageType,
    '#options' => array(
      'normal' => t('Normal'),
      'autoresponder' => t('Auto-responder'),
      'confirmation' => t('Confirmation'),
      'welcome' => t('Welcome')
    ),
    '#required' => TRUE
  );
  $form['message']['subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject'),
    '#default_value' => $message->subject,
    '#required' => TRUE
  );
  if (module_exists('icontact_campaigns')) {
    $campaign_options = array();
    if (!empty($campaign_options)) {
      $form['message']['campaignId'] = array(
        '#type' => 'select',
        '#title' => t('Campaign'),
        '#default_value' => $message->campaignId,
        '#options' => array()
      );
    }
  }
  $form['message']['htmlBody'] = array(
    '#type' => 'textarea',
    '#title' => t('HTML body'),
    '#default_value' => $message->htmlBody
  );
  $form['message']['textBody'] = array(
    '#type' => 'textarea',
    '#title' => t('Text body'),
    '#default_value' => $message->textBody
  );
  $form['save'] = array(
    '#type' => 'submit',
    '#value' => t('Save')
  );
  return $form;
}

function icontact_ui_messages_form_submit($form, &$form_state) {
  $message = $form_state['message'];

  if ($result = $message->save($form_state['values']['message'])) {
    if (isset($form_state['values']['message']['messageId']) && $form_state['values']['message']['messageId'] > 0) {
      drupal_set_message(t('Message successfully updated.'));
    }
    else {
      drupal_set_message(t('Message successfully created.'));
      $form_state['redirect'] = array('admin/icontact/messages', array('clientFolderId' => $message->clientFolderId));
    }
  }
}

function icontact_ui_messages_delete_form(&$form_state, $message) {
  $form = array(
    '#message' => $message
  );
  return confirm_form(
    $form,
    t('Are you sure you want to delete the message %subject?', array('%subject' => $message->subject)),
    drupal_get_destination(),
    t('This action cannot be undone.'),
    t('Delete'),
    t('Cancel'),
    'icontact_messages_delete'
  );
}

function icontact_ui_messages_delete_form_submit($form, &$form_state) {
  $form['#message']->delete();
}

/*******************************************************************************
 * Theme Functions
 ******************************************************************************/

function theme_icontact_ui_messages_list($messages) {
  $output = '';
  $headers = array(
    t('Type'),
    t('Subject'),
    t('Created'),
    t('Actions')
  );
  $rows = array();
  $actions = array(
    'edit' => array(
      'title' => t('Edit'),
      'href' => '',
      'query' => drupal_get_destination()
    ),
    'delete' => array(
      'title' => t('Delete'),
      'href' => '',
      'query' => drupal_get_destination()
    )
  );

  foreach ($messages as $message) {
    $actions['edit']['href'] = 'admin/icontact/messages/'. $message->messageId .'/edit';
    $actions['delete']['href'] = 'admin/icontact/messages/'. $message->messageId .'/delete';
    $row = array(
      array('data' => $message->messageType),
      array('data' => $message->subject),
      array('data' => format_date(strtotime($message->createDate), 'small')),
      array('data' => theme('links', $actions))
    );
    $rows[] = array('data' => $row);
  }

  $output = '<div>'. theme('table', $headers, $rows) .'</div>';
  return $output;
}
